Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(198)

Unified Diff: chrome/browser/search_engines/template_url_parser.cc

Issue 6804032: Add TLS-SRP (RFC 5054) support Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: use system srp and mpi libs, not local copies Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/search_engines/template_url_parser.cc
diff --git a/chrome/browser/search_engines/template_url_parser.cc b/chrome/browser/search_engines/template_url_parser.cc
index e671d63fb1fdff6439442c68e6788674063ca4cb..4b8dd5eee1a8f474341435b46ca9444b2725185d 100644
--- a/chrome/browser/search_engines/template_url_parser.cc
+++ b/chrome/browser/search_engines/template_url_parser.cc
@@ -519,13 +519,14 @@ void CharactersImpl(void *ctx, const xmlChar *ch, int len) {
}
// Returns true if the ref is null, or the url wrapped by ref is
// valid with a spec of http/https.
bool IsHTTPRef(const TemplateURLRef* ref) {
if (ref == NULL)
return true;
GURL url(ref->url());
return (url.is_valid() && (url.SchemeIs(chrome::kHttpScheme) ||
- url.SchemeIs(chrome::kHttpsScheme)));
+ url.SchemeIs(chrome::kHttpsScheme) ||
+ url.SchemeIs(chrome::kHttpsvScheme)));
}
// Returns true if the TemplateURL is legal. A legal TemplateURL is one
@@ -539,7 +540,8 @@ bool IsLegal(TemplateURL* url) {
GURL image_url(image_refs[i].url);
if (!image_url.is_valid() ||
!(image_url.SchemeIs(chrome::kHttpScheme) ||
- image_url.SchemeIs(chrome::kHttpsScheme))) {
+ image_url.SchemeIs(chrome::kHttpsScheme) ||
+ image_url.SchemeIs(chrome::kHttpsvScheme))) {
return false;
}
}
@@ -519,13 +519,14 @@ void CharactersImpl(void *ctx, const xmlChar *ch, int len) {
}
// Returns true if the ref is null, or the url wrapped by ref is
-// valid with a spec of http/https.
+// valid with a spec of http/https/httpsv.
bool IsHTTPRef(const TemplateURLRef* ref) {
if (ref == NULL)

Powered by Google App Engine
This is Rietveld 408576698